==> Data-Sah-0.29.tar.gz: Data-Sah-0.29/lib/Data/Sah/Compiler/human/TH/undef.pm <==
package Data::Sah::Compiler::human::TH::undef;

use 5.010;
use Log::Any '$log';
use Moo;
extends 'Data::Sah::Compiler::human::TH';
with 'Data::Sah::Type::undef';

our $VERSION = '0.29'; # VERSION

sub name { "undefined value" }

sub handle_type {
    my ($self, $cd) = @_;
    my $c = $self->compiler;

    $c->add_ccl($cd, {
        fmt   => ["undefined value", "undefined values"],
        type  => 'noun',
    });
}

1;
# ABSTRACT: perl's type handler for type "undef"

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Compiler::human::TH::undef - perl's type handler for type "undef"

=head1 VERSION

This document describes version 0.29 of Data::Sah::Compiler::human::TH::undef (from Perl distribution Data-Sah), released on 2014-06-30.

=for Pod::Coverage ^(name|clause_.+|superclause_.+|before_.+|after_.+)$

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Data-Sah>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Data-Sah-0.30.tar.gz: Data-Sah-0.30/lib/Data/Sah/Compiler/human/TH/undef.pm <==
package Data::Sah::Compiler::human::TH::undef;

use 5.010;
use Log::Any '$log';
use Moo;
extends 'Data::Sah::Compiler::human::TH';
with 'Data::Sah::Type::undef';

our $VERSION = '0.30'; # VERSION

sub name { "undefined value" }

sub handle_type {
    my ($self, $cd) = @_;
    my $c = $self->compiler;

    $c->add_ccl($cd, {
        fmt   => ["undefined value", "undefined values"],
        type  => 'noun',
    });
}

1;
# ABSTRACT: perl's type handler for type "undef"

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Compiler::human::TH::undef - perl's type handler for type "undef"

=head1 VERSION

This document describes version 0.30 of Data::Sah::Compiler::human::TH::undef (from Perl distribution Data-Sah), released on 2014-10-23.

=for Pod::Coverage ^(name|clause_.+|superclause_.+|before_.+|after_.+)$

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Data-Sah>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
